# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------
"""Async models for Azure Content Understanding."""

from ._patch import AnalyzeAsyncLROPoller

__all__ = ["AnalyzeAsyncLROPoller"]
