# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------
"""Customize generated code here.

Follow our quickstart for examples: https://aka.ms/azsdk/python/dpcodegen/python/customize
"""

__all__: list[str] = []


def patch_sdk():
    """No patches currently required.

    Previous patches for copy_analyzer URL path and status codes have been
    incorporated into the generated code.
    """
    # No patches currently required
